==> EnbanKensa-0.7-20051212-src.tar.gz: EnbanKensa-0.7/win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by EnbanKensa.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDM_THEMESELECT                 0x0020
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_YAKEGUAI_DIALOG             102
#define IDS_THEMESELECT                 102
#define IDD_ENBANKENSA_DIALOG           102
#define IDS_DRIVENOTFOUND               103
#define IDR_MAINFRAME                   128
#define IDB_LOGO                        129
#define IDB_LOGOMASK                    130
#define IDB_AQUA_BUTTON                 131
#define IDB_AQUA_BUTTONFOCUS            132
#define IDB_AQUA_BUTTONMASK             133
#define IDB_AQUA_PROGRESSBG             134
#define IDB_AQUA_PROGRESSFG             135
#define IDB_AQUA_DROPBUTTON             136
#define IDB_AQUA_DROPBUTTONMASK         137
#define IDB_AQUA_COMBOBOXBG             138
#define IDB_AQUA_CLOSEBUTTON            139
#define IDD_MESSAGEDLG                  139
#define IDB_AQUA_CLOSEBUTTONMASK        140
#define IDB_AQUA_MAXBUTTON              141
#define IDI_APPICON                     141
#define IDB_AQUA_MINBUTTON              142
#define IDI_MSGDLG_STOP                 142
#define IDB_AQUA_TITLEACT               143
#define IDI_MSGDLG_QUESTION             143
#define IDB_AQUA_TITLEINACT             144
#define IDI_MSGDLG_EXCLAMATION          144
#define IDB_AQUA_DIALOGBG               145
#define IDB_AQUA_CHECKEDMASK            146
#define IDB_AQUA_CHECKED                147
#define IDB_AQUA_UNCHECKEDMASK          148
#define IDB_AQUA_UNCHECKED              149
#define IDB_BUTTON_NORMAL               150
#define IDB_UNCHECKED                   151
#define IDB_BUTTON_DISABLE              152
#define IDB_BUTTON_FOCUS                153
#define IDB_BUTTON_SELECT               154
#define IDB_CHECKED                     155
#define IDB_DIALOGBG                    157
#define IDB_DROPDOWN                    158
#define IDB_MAXBUTTON                   159
#define IDB_CLOSEBUTTON                 160
#define IDB_MINBUTTON                   161
#define IDB_COMBOBOX                    162
#define IDB_DROPDOWN_MASK               163
#define IDB_APPLOGO                     163
#define IDB_APPLOGO_MASK                164
#define IDD_SETTING                     165
#define IDB_TITLE_INACT                 166
#define IDB_TITLE_ACT                   167
#define IDB_PROGRESSFG                  168
#define IDB_PROGRESSBG                  169
#define IDD_THEMESELECTDLG              170
#define IDB_TOWADA_BUTTON               183
#define IDB_TOWADA_BUTTONFOCUS          184
#define IDB_TOWADA_BUTTONSELECT         185
#define IDB_TOWADA_CHECKED              186
#define IDB_TOWADA_UNCHECKED            187
#define IDB_TOWADA_DROPBUTTON           188
#define IDB_TOWADA_DIALOGBG             189
#define IDB_TOWADA_PROGRESSFG           190
#define IDB_TOWADA_PROGRESSBG           191
#define IDC_STC_DRIVE                   1000
#define IDC_CMB_THEME                   1000
#define IDC_CMB_DRIVE                   1001
#define IDC_STC_DRAWAREA                1002
#define IDC_STC_VERSION                 1003
#define IDC_STC_COPYRIGHT               1004
#define IDC_STC_INFO                    1005
#define IDC_STC_LOGO                    1006
#define IDC_STC_TITLELOGO               1007
#define IDC_CHK_OUT2IN                  1009
#define IDC_STC_RDRETRY                 1010
#define IDC_EDT_RDRETRY                 1011
#define IDC_BTN_DEFRDRETRY              1012
#define IDC_STC_MESSAGE                 1013
#define IDC_BTN_EXTRA                   1014
#define IDC_STC_ICON                    1015

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        166
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1013
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif

==> EnbanKensa-0.8-20061202-src.tar.gz: EnbanKensa-0.8/win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by EnbanKensa.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDM_THEMESELECT                 0x0020
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_YAKEGUAI_DIALOG             102
#define IDS_THEMESELECT                 102
#define IDD_ENBANKENSA_DIALOG           102
#define IDS_DRIVENOTFOUND               103
#define IDR_MAINFRAME                   128
#define IDB_LOGO                        129
#define IDB_LOGOMASK                    130
#define IDB_AQUA_BUTTON                 131
#define IDB_AQUA_BUTTONFOCUS            132
#define IDB_AQUA_BUTTONMASK             133
#define IDB_AQUA_PROGRESSBG             134
#define IDB_AQUA_PROGRESSFG             135
#define IDB_AQUA_DROPBUTTON             136
#define IDB_AQUA_DROPBUTTONMASK         137
#define IDB_AQUA_COMBOBOXBG             138
#define IDB_AQUA_CLOSEBUTTON            139
#define IDD_MESSAGEDLG                  139
#define IDB_AQUA_CLOSEBUTTONMASK        140
#define IDB_AQUA_MAXBUTTON              141
#define IDI_APPICON                     141
#define IDB_AQUA_MINBUTTON              142
#define IDI_MSGDLG_STOP                 142
#define IDB_AQUA_TITLEACT               143
#define IDI_MSGDLG_QUESTION             143
#define IDB_AQUA_TITLEINACT             144
#define IDI_MSGDLG_EXCLAMATION          144
#define IDB_AQUA_DIALOGBG               145
#define IDB_AQUA_CHECKEDMASK            146
#define IDB_AQUA_CHECKED                147
#define IDB_AQUA_UNCHECKEDMASK          148
#define IDB_AQUA_UNCHECKED              149
#define IDB_BUTTON_NORMAL               150
#define IDB_UNCHECKED                   151
#define IDB_BUTTON_DISABLE              152
#define IDB_BUTTON_FOCUS                153
#define IDB_BUTTON_SELECT               154
#define IDB_CHECKED                     155
#define IDB_DIALOGBG                    157
#define IDB_DROPDOWN                    158
#define IDB_MAXBUTTON                   159
#define IDB_CLOSEBUTTON                 160
#define IDB_MINBUTTON                   161
#define IDB_COMBOBOX                    162
#define IDB_DROPDOWN_MASK               163
#define IDB_APPLOGO                     163
#define IDB_APPLOGO_MASK                164
#define IDD_SETTING                     165
#define IDB_TITLE_INACT                 166
#define IDD_DISCINFO                    166
#define IDB_TITLE_ACT                   167
#define IDB_PROGRESSFG                  168
#define IDB_PROGRESSBG                  169
#define IDD_THEMESELECTDLG              170
#define IDB_TOWADA_BUTTON               183
#define IDB_TOWADA_BUTTONFOCUS          184
#define IDB_TOWADA_BUTTONSELECT         185
#define IDB_TOWADA_CHECKED              186
#define IDB_TOWADA_UNCHECKED            187
#define IDB_TOWADA_DROPBUTTON           188
#define IDB_TOWADA_DIALOGBG             189
#define IDB_TOWADA_PROGRESSFG           190
#define IDB_TOWADA_PROGRESSBG           191
#define IDS_CANT_GET_DISC_TYPE          195
#define IDS_INS_MEDIA_IS_BLANK          196
#define IDS_STATUS_STRING_READ_NG_      197
#define IDS_MSG_STATUS_STRING_          198
#define IDS_COMPLETE_WITH_READ_WRROR    199
#define IDS_COMPLETE_WITH_C2_ERROR      200
#define IDS_COMPLETE_WITHOUT_ERROR      201
#define IDS_ABORTED                     202
#define IDS_ABORTED_BECAUSE_ERROR       203
#define IDS_DRIVE_INIT_ERROR            204
#define IDS_WAITING_READY               205
#define IDS_INSERT_DISC                 206
#define IDS_QUICK_BLANK                 207
#define IDS_COMMAND_ERROR               208
#define IDS_MEM_ALLOC_ERROR             209
#define IDS_READING_TRACK_              210
#define IDS_MAKING_DISCINFO_            211
#define IDS_SYSTEM                      212
#define IDS_VOLUME                      213
#define IDS_VOLUMESET                   214
#define IDS_PUBLISHER                   215
#define IDS_PREPARER                    216
#define IDS_APPLICATION                 217
#define IDS_CREATION_DATE_TIME          218
#define IDS_OTHER                       219
#define IDC_STC_DRIVE                   1000
#define IDC_CMB_THEME                   1000
#define IDC_CMB_DRIVE                   1001
#define IDC_STC_DRAWAREA                1002
#define IDC_STC_VERSION                 1003
#define IDC_STC_COPYRIGHT               1004
#define IDC_STC_INFO                    1005
#define IDC_STC_LOGO                    1006
#define IDC_STC_TITLELOGO               1007
#define IDC_CHK_OUT2IN                  1009
#define IDC_STC_RDRETRY                 1010
#define IDC_EDT_RDRETRY                 1011
#define IDC_BTN_DEFRDRETRY              1012
#define IDC_STC_MESSAGE                 1013
#define IDC_BTN_DISCINFO                1013
#define IDC_BTN_EXTRA                   1014
#define IDC_LST_TRACKS                  1014
#define IDC_STC_ICON                    1015
#define IDC_EDT_INFO                    1015

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        167
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1016
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
